@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+import argparse
 import os
 import subprocess
 import tempfile
@@ -13,8 +14,6 @@ from types import TracebackType
 # TODO: replace Optinal with | None
 from typing import Optional
 
-from ccbuilder import Builder, CompilerProject, Revision
-
 from diopter.utils import run_cmd, save_to_tmp_file
 
 
@@ -135,23 +134,36 @@ class SourceProgram:
         return replace(self, code=new_code)
 
 
-def parse_compiler_revision(compiler_exe: Path) -> Revision:
-    """Tries to parse the compiler revision of the given executable (clang/gcc).
+Revision = str
+
+
+def parse_compiler(compiler_exe: Path) -> tuple[CompilerProject, Revision] | None:
+    """Tries to find the compiler project parse the revision
+    of the given executable (clang/gcc).
 
     Args:
         compiler_exe (Path): a path to the compiler executable
 
     Returns:
-        Revision:
-            the parsed version
+        (CompilerProject, Revision) | None :
+            compiler project (LLVM or GCC)  and the parsed version, None if
+            the parsing failed
     """
     info = run_cmd(f"{str(compiler_exe)} -v".split())
     for line in info.stderr.splitlines():
         if "clang version" in line:
-            return line[len("clang version") :].strip()
+            return CompilerProject.LLVM, line[len("clang version") :].strip()
         if "gcc version" in line:
-            return line[len("gcc version") :].strip().split()[0]
-    return "unknown"
+            return CompilerProject.GCC, line[len("gcc version") :].strip().split()[0]
+    return None
+
+
+class CompilerProject(Enum):
+    GCC = 0
+    LLVM = 1
+
+    def to_string(self) -> str:
+        return "gcc" if self == CompilerProject.GCC else "clang"
 
 
 @dataclass(frozen=True)
@@ -184,9 +196,9 @@ class CompilerExe:
         gcc = which("gcc")
         assert gcc, "gcc is not in PATH"
         gcc_path = Path(gcc)
-        return CompilerExe(
-            CompilerProject.GCC, gcc_path, parse_compiler_revision(gcc_path)
-        )
+        project_revision = parse_compiler(gcc_path)
+        assert project_revision is not None
+        return CompilerExe(CompilerProject.GCC, gcc_path, project_revision[1])
 
     @staticmethod
     def get_system_clang() -> CompilerExe:
@@ -197,9 +209,15 @@ class CompilerExe:
         clang = which("clang")
         assert clang, "clang is not in PATH"
         clang_path = Path(clang)
-        return CompilerExe(
-            CompilerProject.LLVM, clang_path, parse_compiler_revision(clang_path)
-        )
+        project_revision = parse_compiler(clang_path)
+        assert project_revision is not None
+        return CompilerExe(CompilerProject.LLVM, clang_path, project_revision[1])
+
+    @staticmethod
+    def from_path(cc: Path) -> CompilerExe:
+        project_revision = parse_compiler(cc)
+        assert project_revision
+        return CompilerExe(project_revision[0], cc, project_revision[1])
 
 
 class OptLevel(Enum):
@@ -339,21 +357,6 @@ class CompilationSetting:
     system_include_paths: tuple[str, ...] = tuple()
     # TODO: timeout_s: int = 8
 
-    # TODO: drop this, ccbuilder should be independent of this file
-    def with_revision(self, revision: Revision, builder: Builder) -> CompilationSetting:
-        new_compiler = CompilerExe(
-            self.compiler.project,
-            builder.build(self.compiler.project, revision, True),
-            revision,
-        )
-        return CompilationSetting(
-            compiler=new_compiler,
-            opt_level=self.opt_level,
-            flags=self.flags,
-            include_paths=self.include_paths,
-            system_include_paths=self.system_include_paths,
-        )
-
     def get_compilation_base_cmd(self, program: SourceProgram) -> list[str]:
         """Combines the program's flags with the flags of this compilation
         setting.
@@ -760,3 +763,102 @@ class CComp:
         except subprocess.CalledProcessError:
             return False
         return True
+
+
+def compiler_settings_parser() -> argparse.ArgumentParser:
+    """Create an ArgumentParser for CompilationSetting.
+    Should be integrated with another parser via the `parent`
+    constructor argument as it does not create the `help` output
+    itself (otherwise, it would not be composable anymore).
+
+    Args:
+
+    Returns:
+        argparse.ArgumentParser:
+    """
+    # We do not add the help hear so this parser can be extendend or extend another one.
+    parser = argparse.ArgumentParser(add_help=False)
+
+    parser.add_argument(
+        "compiler",
+        type=Path,
+    )
+    parser.add_argument("-I", action="append")
+    parser.add_argument("-O")
+    parser.add_argument("-isystem", action="append")
+    parser.add_argument("-D", action="append")
+    parser.add_argument("-o")
+    # XXX: Parsed bug ignored for now (TM)
+    parser.add_argument("-c", action="store_true")
+    parser.add_argument("-S", action="store_true")
+
+    return parser
+
+
+def parse_compile_settings(
+    parsed_args: argparse.Namespace, rest: list[str]
+) -> tuple[CompilationSetting, tuple[str, ...], list[str], str | None]:
+    """Parse a CompilationSetting from the provided parsed_args and rest.
+    The parser that yielded `parsed_args` and `rest` must include the
+    `compiler_settings_parser()` as a parent.
+
+    Args:
+        parsed_args (argparse.Namespace): Argument namespace
+        rest (list[str]): Unparsed output
+
+    Returns:
+        tuple[CompilationSetting, tuple[str, ...], list[str], str | None]:
+            - CompilationSetting
+            - macros set or unset
+            - source files provided
+            - specified output file
+    """
+
+    CPP_EXT = (".cc", ".cxx", ".cpp")
+    C_EXT = (".c",)
+
+    sources: list[str] = []
+    flags: list[str] = []
+    for arg in rest:
+        if arg.lower().endswith(CPP_EXT + C_EXT):
+            sources.append(arg)
+        else:
+            flags.append(arg)
+
+    include_paths: tuple[str, ...] = tuple(parsed_args.I) if parsed_args.I else tuple()
+    system_include_paths: tuple[str, ...] = (
+        tuple(parsed_args.isystem) if parsed_args.isystem else tuple()
+    )
+    macro_definitions: tuple[str, ...] = (
+        tuple(parsed_args.D) if parsed_args.D else tuple()
+    )
+
+    cexe = CompilerExe.from_path(Path(parsed_args.compiler))
+
+    csetting = CompilationSetting(
+        compiler=cexe,
+        opt_level=OptLevel.from_str(parsed_args.O),
+        include_paths=include_paths,
+        system_include_paths=system_include_paths,
+        flags=tuple(flags),
+    )
+    return csetting, macro_definitions, sources, parsed_args.o
+
+
+def parse_compile_settings_from_string(
+    s: str,
+) -> tuple[CompilationSetting, tuple[str, ...], list[str], str | None]:
+    """Parse the compile settings provided in `s`.
+
+    Args:
+        s (str): compilation command string to be parsed.
+
+    Returns:
+        tuple[CompilationSetting, tuple[str, ...], list[str], str | None]:
+            see `parse_compile_settings`.
+    """
+    parser = argparse.ArgumentParser(parents=[compiler_settings_parser()])
+    parsed_args, rest = parser.parse_known_intermixed_args(
+        [p.strip() for p in s.split() if p]
+    )
+    return parse_compile_settings(parsed_args, rest)
